# coding=utf-8

from setuptools import setup, find_packages

setup(
    name='hehehaha',
    version='1.0.0',
    description=(
        '我用来学习测试的'
    ),
    long_description=open('README.md').read(),
    author='CuiWeiming',
    author_email='cuiweiming1110@163.com',
    maintainer='CuiWeiming',
    maintainer_email='cuiweiming1110@163.com',
    license='GNU General Public License v3 (GPLv3)',
    packages=find_packages(),
    platforms=["all"],
    url='https://github.com/XIHEHA/hehehaha',
    classifiers=[
        'Development Status :: 4 - Beta',
        'Operating System :: OS Independent',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: GNU General Public License v3 (GPLv3)',
        'Programming Language :: Python',
        'Programming Language :: Python :: Implementation',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Topic :: Software Development :: Libraries'
    ],
)
